@@ -11,15 +11,17 @@ import time
 import django
 import eanoui
 from django import template
-
+from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
-from django.urls import reverse, is_valid_path
+from django.urls import is_valid_path, reverse
 from django.utils.encoding import force_text
 from django.utils.functional import Promise
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
+from types import MappingProxyType
+
 
 register = template.Library()
 
@@ -475,7 +477,11 @@ def simple_version():
 def get_model_url(context):
     # reverse()
     opts = context.get("opts")
-    key = "admin:{}_{}_changelist".format(opts.app_label, opts.model_name)
+    request = context.get("request")
+
+    key = "{}:{}_{}_changelist".format(
+        get_current_app(request), opts.app_label, opts.model_name
+    )
     url = reverse(key)
     preserved_filters = dict(parse_qsl(context.get("preserved_filters")))
     if "_changelist_filters" in preserved_filters:
@@ -484,9 +490,23 @@ def get_model_url(context):
     return url
 
 
+def get_current_app(request):
+    app = None
+    if hasattr(request, 'current_app'):
+        app = getattr(request, 'current_app')
+    elif hasattr(request, 'model_admin'):
+        model_admin = getattr(request, 'model_admin')
+        if hasattr(model_admin, 'opts'):
+            opts = getattr(model_admin, 'opts')
+            app = opts.app_config.name
+    return app
+
+
 @register.simple_tag(takes_context=True)
 def get_model_ajax_url(context):
     opts = context.get("opts")
+    request = context.get("request")
+
     key = "admin:{}_{}_ajax".format(opts.app_label, opts.model_name)
     try:
         return reverse(key)
